#PBS -l nodes=6:ppn=4:infiniband
#PBS -l walltime=13:0:0
#PBS -e stderr.log
#PBS -o stdout.log

from ase.lattice.surface import fcc111
from ase.optimize import QuasiNewton
from ase.constraints import FixAtoms
from gpaw import GPAW, Mixer, PoissonSolver
from gpaw.utilities import h2gpts

system = fcc111('Pt', a=3.999, size=(2, 2, 10), orthogonal=True)
system.center(vacuum=6.0, axis=2)

calc = GPAW(mode='lcao', basis='dzp',
            mixer=Mixer(0.04, 7, 50.0),
            poissonsolver=PoissonSolver(relax='GS', eps=1e-9),
            xc='RPBE',
            kpts=(4, 6, 1),
            nbands=len(system) * 6,
            txt='gpaw.relaxlayers.txt',
            gpts=h2gpts(0.2, system.get_cell(), idiv=8))
system.set_calculator(calc)

tags = system.get_tags()
mask = (tags <= 7) & (tags >= 4)
system.set_constraint(FixAtoms(mask=mask))

opt = QuasiNewton(system, trajectory='opt.traj', logfile='opt.log')
opt.run(fmax=0.05)
